@@ -32,6 +32,9 @@ COPIER_OUTPUT_SUBDIR_NAME = "output-subdir"
 COPIER_OUTPUT_SUBDIR_DIR = COPIERS_DIR / COPIER_OUTPUT_SUBDIR_NAME
 COPIER_OUTPUT_SUBDIR_VERSION = "783e158aea9852664d497b19f6ba7b8b"
 COPIER_OUTPUT_SUBDIR_MODIFIED_VERSION = "does not matter yet for tests"
+COPIER_FROM_COOKIECUTTER_ONE_NAME = "from-cookiecutter-one"
+COPIER_FROM_COOKIECUTTER_ONE_DIR = COPIERS_DIR / COPIER_FROM_COOKIECUTTER_ONE_NAME
+COPIER_FROM_COOKIECUTTER_ONE_VERSION = "5a4e3d4bf1fe026cb6e63dbca154825a"
 COPIER_REMOTE_URL = "https://github.com/nickderobertis/copier-simple-example"
 COPIER_REMOTE_NAME = "copier-simple-example"
 COPIER_REMOTE_VERSION_1 = "c7e1ba1bfb141e9c577e7c21ee4a5d3ae5dde04d"
@@ -42,6 +45,9 @@ CONFIG_1_PATH = CONFIGS_DIR / "flexlate.json"
 CONFIG_SUBDIR_1 = CONFIG_1_PATH / "subdir1"
 CONFIG_SUBDIR_2 = CONFIGS_DIR / "subdir2"
 
+PROJECTS_DIR = INPUT_FILES_DIR / "projects"
+NESTED_PROJECT_DIR = PROJECTS_DIR / "nested"
+
 PROJECT_CONFIGS_DIR = INPUT_FILES_DIR / "project_configs"
 PROJECT_CONFIGS_ROOT_DIR = PROJECT_CONFIGS_DIR / "root"
 PROJECT_CONFIGS_ROOT_CONFIG_PATH = PROJECT_CONFIGS_ROOT_DIR / "flexlate-project.json"
